@@ -24,8 +24,15 @@ class REPLWrapTestCase(unittest.TestCase):
 
     def test_bash(self):
         bash = replwrap.bash()
-        res = bash.run_command("time")
-        assert 'real' in res, res
+        res = bash.run_command("alias")
+        assert 'alias' in res, res
+
+        try:
+            bash.run_command('')
+        except ValueError:
+            pass
+        else:
+            assert False, "Didn't raise ValueError for empty input"
 
     def test_pager_as_cat(self):
         " PAGER is set to cat, to prevent timeout in ``man sleep``. "
@@ -33,6 +40,15 @@ class REPLWrapTestCase(unittest.TestCase):
         res = bash.run_command('man sleep', timeout=5)
         assert 'SLEEP' in res, res
 
+    def test_bash_env(self):
+        """env, which displays PS1=..., should not mess up finding the prompt.
+        """
+        bash = replwrap.bash()
+        res = bash.run_command("env")
+        self.assertIn('PS1', res)
+        res = bash.run_command("echo $HOME")
+        assert res.startswith('/'), res
+
     def test_long_running_multiline(self):
         " ensure the default timeout is used for multi-line commands. "
         bash = replwrap.bash()
@@ -69,7 +85,7 @@ class REPLWrapTestCase(unittest.TestCase):
         self.assertEqual(res.strip().splitlines(), ['1 2', '3 4'])
 
     def test_existing_spawn(self):
-        child = pexpect.spawn("bash", timeout=5, echo=False, encoding='utf-8')
+        child = pexpect.spawn("bash", timeout=5, encoding='utf-8')
         repl = replwrap.REPLWrapper(child, re.compile('[$#]'),
                                     "PS1='{0}' PS2='{1}' "
                                     "PROMPT_COMMAND=''")
